<?php

include 'config.php';

function error($code) {

    switch($code) {
        case 404 : $str = 'Not Found'; break;
        case 405 : $str = 'Method Not Allowed'; break;
    }

    header('HTTP/1.1 ' . $code . ' ' . $str);
    echo '<h1>' . $code . ' ' . $str . '</h1>';
}

$requestUri = $_SERVER['REQUEST_URI'];

$regex = '|^/storage/([0-9]*)/([0-9a-z]*)$|';

$method = $_SERVER['REQUEST_METHOD'];

if ($method!='HEAD' && $method!='GET') {
    error(405);
    die(1);
}

if (!preg_match($regex,$requestUri,$matches)) {
    error(404);
    die(1);
}

list(, $mediaId, $fileType) = $matches;

$filePath = FM_STORAGEPATH . '/';

switch(FM_DIRSTRUCTURE) {
    case 'hash3' :
        $hash = str_split(md5($mediaId),3);
        $filePath.=implode('/',array_slice($hash,0,3));
        break;
    case 'hash4' :
        $hash = str_split(md5($mediaId),2);
        $filePath.=implode('/',array_slice($hash,0,4));
        break;
}

$filePath.= '/'. $mediaId . '_' . $fileType . '.';
// Because we cannot guess the extension, we must do a search first

$files = glob($filePath . '*');

if (count($files)==0) {
    error(404);
    die(1);
}

$filePath = $files[0];

header('Content-Length: ' . filesize($filePath));

// We need to determine the filetype based on known extensions,
// because using the operating system is too slow and often
// unreliable.

$extension = substr($filePath,strrpos($filePath,'.')+1);
switch(strtolower($extension)) {
    case 'jpg' : $mime = 'image/jpeg'; break;
    case 'mp3' : $mime = 'audio/mp3'; break;
    case 'ogg' : $mime = 'audio/ogg'; break;
    case 'mp4' : $mime = 'video/mp4'; break;
    case 'ogv' : $mime = 'video/ogg'; break;
    case 'flv' : $mime = 'video/flv'; break;
    case 'mpg' : $mime = 'video/mpeg'; break;
    case '3gp' : $mime = 'video/3gpp'; break;
    default    : $mime = 'application/octet-stream'; break;
}
     
header('Content-Type: ' . $mime);
//cache for 14 days
header('Cache-control: ', 'max-age=' . 3600*24*14);

switch($method) {
    case 'GET' :
        readfile($filePath);
        break;
    case 'HEAD' :
        // Don't do anything
        break;
}

